@@ -202,12 +202,14 @@ async fn main() -> CommandResult {
                 .unwrap();
             let link_file = sub_arg_matches.is_present("link_file");
             let update_image = sub_arg_matches.is_present("update_image");
+            let update_animation_url = sub_arg_matches.is_present("update_animation_url");
             command_update_metadata(
                 &Arweave::default(),
                 paths_iter,
                 manifest_path,
                 link_file,
                 update_image,
+                update_animation_url,
             )
             .await
         }
@@ -555,7 +557,8 @@ fn get_app() -> App<'static, 'static> {
                 .arg(file_paths_arg())
                 .arg(manifest_path_arg())
                 .arg(link_file_arg())
-                .arg(update_image_arg()),
+                .arg(update_image_arg())
+                .arg(update_animation_url_arg())
         )
         .subcommand(
             SubCommand::with_name("update-status")
@@ -629,7 +632,7 @@ fn get_app() -> App<'static, 'static> {
         .subcommand(
             SubCommand::with_name("write-metaplex-items")
                 .about("Writes metaplex items to file.")
-                .arg(file_paths_arg().required(true))
+                .arg(file_paths_arg().required(true).validator(is_json_file_path))
                 .arg(manifest_path_arg())
                 .arg(link_file_arg())
                 .after_help(
@@ -810,6 +813,15 @@ fn tags_arg<'a, 'b>() -> Arg<'a, 'b> {
         )
 }
 
+fn update_animation_url_arg<'a, 'b>() -> Arg<'a, 'b> {
+    Arg::with_name("update_animation_url")
+        .long("update-animation-url")
+        .value_name("UPDATE_ANIMATION_URL")
+        .required(false)
+        .takes_value(false)
+        .help("Update animation_url key in metadata file with link from manifest file.")
+}
+
 fn update_image_arg<'a, 'b>() -> Arg<'a, 'b> {
     Arg::with_name("update_image")
         .long("update-image")
@@ -926,6 +938,23 @@ fn is_valid_file_path(path_str: String) -> Result<(), String> {
     }
 }
 
+fn is_json_file_path(path_str: String) -> Result<(), String> {
+    match path_str.parse::<PathBuf>() {
+        Ok(p) => {
+            if p.is_file() {
+                if p.extension().unwrap() == "json" {
+                    Ok(())
+                } else {
+                    Err(format!("Path does not have a json extension."))
+                }
+            } else {
+                Err(format!("Path is not file."))
+            }
+        }
+        Err(_) => Err(format!("Not a valid path.")),
+    }
+}
+
 // ====================
 // Helpers
 // ====================
