@@ -39,6 +39,13 @@ impl std::fmt::Display for StatusCode {
         }
     }
 }
+pub struct FilterElements<'a> {
+    pub raw_status: &'a Option<RawStatus>,
+    pub status: &'a StatusCode,
+}
+pub trait Filterable {
+    fn get_filter_elements(&self) -> FilterElements;
+}
 
 /// Data structure for tracking transaction statuses.
 #[derive(Serialize, Deserialize, Debug, PartialEq, Clone)]
@@ -86,6 +93,15 @@ impl Status {
     }
 }
 
+impl Filterable for Status {
+    fn get_filter_elements(&self) -> FilterElements {
+        FilterElements {
+            raw_status: &self.raw_status,
+            status: &self.status,
+        }
+    }
+}
+
 impl QuietDisplay for Status {
     fn write_str(&self, _w: &mut dyn fmt::Write) -> fmt::Result {
         Ok(())
@@ -197,6 +213,15 @@ impl BundleStatus {
     }
 }
 
+impl Filterable for BundleStatus {
+    fn get_filter_elements(&self) -> FilterElements {
+        FilterElements {
+            raw_status: &self.raw_status,
+            status: &self.status,
+        }
+    }
+}
+
 impl QuietDisplay for BundleStatus {
     fn write_str(&self, _w: &mut dyn fmt::Write) -> fmt::Result {
         Ok(())
